#include "linux.h"

#define ADDITIONAL_FEATURES ADD_FEATURE("SPARC")

#define	SPARC
/* #define SGC */

#define PTR_ALIGN 8

